@@ -11,11 +11,11 @@ Keyword::DEVELOPMENT - Have code blocks which don't exist unless you ask for the
 
 =head1 VERSION
 
-Version 0.04
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -167,7 +167,7 @@ As SawyerX pointed out, can replicate the functionality of this module in pure
 Perl, if desired:
 
     use constant PRODUCTION => !!$ENV{PRODUCTION};
-    DEVELOPMENT {expensive_debugging_code()} unless PRODUCTION;
+    do {expensive_debugging_code()} unless PRODUCTION;
 
 Versus:
 
